==> idealstan_0.2.7.tar.gz: idealstan/R/idealstan-internal.R <==

.Random.seed <-
c(403L, 10L, -25182749L, -1011638655L, -1866196752L, -1436149874L, 
1092610297L, -1603636597L, -883502406L, -1554408004L, -427211009L, 
2047085141L, 1545088364L, -1121409598L, -771799523L, -1535082857L, 
1530886142L, -1212595272L, 63168411L, -132512263L, -646707896L, 
486903926L, -314892879L, -1472183325L, 1395327154L, -1570427644L, 
-315986361L, 2146490653L, -1455302764L, -1689085126L, 537962373L, 
-1226501025L, 432660198L, 462398832L, 186945171L, -1966655695L, 
-697438752L, 4135550L, -637433591L, 1455254331L, 810361610L, 
-899847444L, -146151569L, -145569627L, -1088839076L, -577236430L, 
-1467655891L, 1066344423L, 2089969422L, 755497192L, 1893010155L, 
1125909385L, 458252056L, -1473838522L, 1324524193L, -136477389L, 
795524258L, -1052331116L, 1093872151L, 2136223245L, -1748841692L, 
-163227894L, 1144126069L, 118974927L, -2012679466L, 1410766464L, 
-1389160253L, 412243553L, 800157392L, 1349400622L, 1305857497L, 
-436751893L, 977351770L, 1381846556L, 790904607L, -3812491L, 
1684838924L, 1247943650L, -1096095555L, -1688365257L, -1044881442L, 
-157151976L, -984620933L, -2041973223L, 1964351144L, 1174826070L, 
8513745L, 65918083L, -1200703726L, 1627230884L, -638853529L, 
-1175720003L, -1902919372L, -1560092006L, 257482981L, 2084479615L, 
28756998L, 417038224L, -1634770381L, 210123217L, 729967488L, 
-735132066L, -1418682967L, 145230939L, -1690422166L, -694579956L, 
1190170447L, -1837216763L, -103984452L, 480084882L, -1300021107L, 
67114695L, -1805008978L, 1843104264L, -507154933L, 1274816233L, 
231956920L, -49750426L, 203684609L, -1869230701L, -1251727806L, 
238451188L, -628841481L, -2060281875L, 879431812L, -1932548438L, 
-26084331L, 929598639L, 1960952502L, -660176672L, -2006176733L, 
552072001L, -673145296L, -1697711026L, -1918987079L, 1984630987L, 
-1856979590L, 2043043964L, -1051589441L, 101486997L, 2013149612L, 
-2364542L, 155554141L, -193572777L, 1162536766L, 1482321784L, 
461112411L, 1787925433L, -1525534200L, -597215050L, -167059471L, 
196651555L, -929463694L, -813319996L, 1882140295L, -657496483L, 
-1758476204L, -1780901254L, -4783675L, 991154975L, 2019794598L, 
849612848L, 1683919571L, 1430702321L, -1716997088L, 187060926L, 
-775219511L, -1320471429L, 126724682L, 1239109292L, 2139392431L, 
-1442897563L, 78950172L, -1990569102L, 1495322605L, 501407783L, 
1052809294L, -745284440L, 678646443L, -1164625975L, 1210805208L, 
2059041414L, 1995012961L, -877101325L, 990019938L, 979984340L, 
-893695273L, 1792487629L, -649541532L, -1665735094L, -1341353035L, 
-1679143153L, 820005910L, 55383744L, 802803843L, -1317385055L, 
1186079376L, -1254710930L, -1059184871L, 492131243L, 191529370L, 
89191772L, -169071521L, 1990079541L, 1993609164L, -2138625246L, 
550483325L, -1460128137L, 266096542L, 564293208L, 2070120379L, 
-1722914471L, 1913545448L, -52323562L, 1492446353L, -2118065853L, 
2039147602L, 1283567332L, 1931385127L, -688735875L, 2128113780L, 
1392849498L, 741039781L, -606016321L, -1468813498L, -999060016L, 
725102579L, 1378334481L, 1329985344L, 458301904L, -998906526L, 
1137841128L, -1886709812L, -1340483844L, -1079406606L, 856980608L, 
-1450673932L, 1199617160L, 1443456314L, -506903728L, -863753108L, 
1528946836L, -1284982446L, -1117372704L, -273936180L, -1425024864L, 
-136816254L, 1504573672L, 1175427308L, 102832188L, -373120910L, 
-187946896L, -1965628892L, 2089001528L, 1723181594L, 103944400L, 
-2032159172L, -79410028L, -964127614L, -1730607168L, 1768402236L, 
-2035630448L, -1881418718L, 1037668360L, 82623628L, 1088536604L, 
649372818L, -1370862464L, -1623210988L, 2141315880L, -1712974790L, 
347516112L, -1899416468L, 214013620L, 141680658L, -1346519072L, 
655199180L, -326713888L, 1912835106L, -1033611992L, -383231732L, 
-1413296580L, -819477262L, -518227728L, -1308969148L, -1884950440L, 
545325626L, 870336752L, -1540840772L, -804828652L, 1182379202L, 
465712736L, 1713145212L, 1563059408L, 1340191778L, -97171288L, 
378314124L, -11230788L, -543029198L, -1448651968L, 731913908L, 
-340356792L, -1715850566L, -1983217904L, 366674156L, 252328020L, 
-525089006L, 1891492256L, -1133090868L, 2082283360L, -932533054L, 
-723857880L, 953510316L, -1781914820L, 965763954L, 294817584L, 
121208868L, 529546808L, -1559915814L, 2099566480L, -26544900L, 
-38580844L, 1999733570L, -642463232L, 258836540L, 943964752L, 
420561058L, -2040478904L, -1897186804L, 148183772L, 1218162770L, 
1144360064L, -1768667308L, -1756250136L, -641453318L, 990660432L, 
1066263596L, 984500596L, 1522708114L, 822076000L, 2055516300L, 
1064522080L, 2070255842L, -485135192L, -754329908L, -104474116L, 
-1173582926L, 117523440L, 1040286148L, 1863335256L, -789581446L, 
-1972080208L, -1721226820L, 268369492L, 1009916354L, -345750752L, 
-2089012292L, 1308479568L, 1555323874L, 2044297064L, -1612228788L, 
1067003644L, 1063569138L, 389053696L, 1556511860L, 651193864L, 
2059150778L, -400349744L, -2141657108L, -2142393452L, -704747310L, 
-1589947296L, 2060225868L, -50892000L, 585050754L, 1672991208L, 
-501064724L, 703876668L, 945833586L, 1687645040L, -1392112348L, 
-1598907848L, -1725791846L, 103402960L, -1115568708L, 232263316L, 
2102325890L, -712061504L, 1589991228L, -52714864L, 993175330L, 
203310600L, 731898636L, 1554576284L, -744670190L, -759297152L, 
1436224276L, -1909058264L, -732848070L, -552438832L, -1536730516L, 
-1671648204L, 380121234L, -1879082656L, -957039284L, -186772000L, 
-1852081246L, -1852015704L, 267807884L, -822615108L, -848243598L, 
-338679824L, 930747460L, 1835673688L, 1555771450L, 1371547760L, 
-2079297988L, 1404790548L, -574059838L, -631754016L, 779854972L, 
-1739731760L, -2051046494L, -2091483608L, -350965492L, 900249532L, 
1038549298L, -1644898112L, 174764596L, 1113057992L, 241291962L, 
-437035888L, -1158842644L, -226912684L, -1041320302L, -626972896L, 
1864292300L, -28694304L, -1914036542L, -1301842904L, -769606740L, 
-1577649476L, -1741397518L, -1803069904L, 953358244L, -118443592L, 
-1504638118L, -761764720L, 750467964L, -1880510700L, -1051235006L, 
166915840L, -63603780L, -1812836528L, 1815376162L, -346813880L, 
1600120514L, 444466903L, 1602397985L, 739532518L, -314312732L, 
1397982997L, 1306828607L, 1991695064L, 213368566L, -568846077L, 
-1405220283L, 1398540898L, 2023950800L, 345061113L, -608500693L, 
1665909660L, -1218487350L, 1751086271L, 809866761L, -1801183458L, 
344778444L, 989677213L, -416492761L, 1084095824L, 1883849710L, 
-763777893L, 1544898301L, 416959978L, -1506124152L, 159107121L, 
-940354909L, -2131723612L, -1451136174L, 1130652327L, 149208817L, 
-1312928202L, 485102292L, -1638930843L, -343460753L, 1269534376L, 
644803590L, 1026349363L, 105874837L, 1445071346L, 1382311488L, 
-127203415L, -2043074021L, -1363024916L, -383745030L, -1637208017L, 
-1152114631L, 116421198L, -212610404L, 828864525L, -2005687177L, 
1371501696L, -883105058L, -1973218901L, 329124525L, 234278682L, 
-221294632L, -1758127039L, 1226263283L, -1748038380L, 1326405794L, 
-21219913L, -348747391L, -562172026L, -1443889724L, 1385798901L, 
-2142833313L, -672647240L, -1645675882L, 1078338723L, -1629331867L, 
-90633342L, 1310451952L, 708513945L, 987457675L, 2000736636L, 
879972266L, 2052648927L, -998089367L, -2005606018L, -1180552852L, 
-1978897987L, 1896798855L, -1116676496L, 1558488334L, 1903503931L, 
1928106269L, 853599178L, -1180459800L, -2085732399L, -531238461L, 
-1823606076L, 233126258L, -327146425L, -1655658479L, 1903292822L, 
1174512884L, -37794171L, 692905935L, 811599560L, -801071258L, 
656459155L, 1151104757L, -869828910L, 991740192L, -151162615L, 
1840313915L, -214242420L, 656927258L, -424379761L, -554064423L, 
1816685166L, -1822737924L, 832396141L, 162735383L, -1644949280L, 
1450788542L, 1498391691L, -630910195L, 583807802L, 1018858360L, 
-1714702047L, -1333931565L, 1217429748L, 899727746L, -1409547241L, 
2090226401L, 1974438950L, 73062692L, -1590224427L, 1875948927L, 
-77542376L, 784548662L, -28183101L, -551650299L, 1792382882L, 
-851856496L, 1338357561L, -47094805L, -1823492900L, -2081288950L, 
-2026916865L, 1976485449L, 1206318046L, 206949260L, -1162278051L, 
174685031L, 743813264L, -1900990802L, 1033046875L, 155999037L, 
930714026L, 362217032L, -838316431L, -1228648477L, -895149340L, 
-232250862L, -1254320665L, 1257390513L, -1115109386L, 1448999444L, 
195626277L, -924994001L, -54758424L, -978942778L, 1919340052L
)

==> idealstan_0.5.1.tar.gz: idealstan/R/idealstan-internal.R <==

# define some global variables for use with dplyr
if(getRversion() >= "2.15.1")  utils::globalVariables(c('get_samples2',
                                                        'abs_data',
                                                        'abs_mid',
                                                        'bill_pos',
                                                        'group_id',
                                                        'Iteration',
                                                        'outcome',
                                                        'person_id',
                                                        'reg_data',
                                                        'reg_mid',
                                                        'time_id',
                                                        'time_point',
                                                        'true_pt',
                                                        'variables',
                                                        'item_high',
                                                        'item_low',
                                                        'item_median',
                                                        '5%',
                                                        '95%',
                                                        ":=",
                                                        'item_type'))

.Random.seed <-
c(403L, 10L, -25182749L, -1011638655L, -1866196752L, -1436149874L, 
1092610297L, -1603636597L, -883502406L, -1554408004L, -427211009L, 
2047085141L, 1545088364L, -1121409598L, -771799523L, -1535082857L, 
1530886142L, -1212595272L, 63168411L, -132512263L, -646707896L, 
486903926L, -314892879L, -1472183325L, 1395327154L, -1570427644L, 
-315986361L, 2146490653L, -1455302764L, -1689085126L, 537962373L, 
-1226501025L, 432660198L, 462398832L, 186945171L, -1966655695L, 
-697438752L, 4135550L, -637433591L, 1455254331L, 810361610L, 
-899847444L, -146151569L, -145569627L, -1088839076L, -577236430L, 
-1467655891L, 1066344423L, 2089969422L, 755497192L, 1893010155L, 
1125909385L, 458252056L, -1473838522L, 1324524193L, -136477389L, 
795524258L, -1052331116L, 1093872151L, 2136223245L, -1748841692L, 
-163227894L, 1144126069L, 118974927L, -2012679466L, 1410766464L, 
-1389160253L, 412243553L, 800157392L, 1349400622L, 1305857497L, 
-436751893L, 977351770L, 1381846556L, 790904607L, -3812491L, 
1684838924L, 1247943650L, -1096095555L, -1688365257L, -1044881442L, 
-157151976L, -984620933L, -2041973223L, 1964351144L, 1174826070L, 
8513745L, 65918083L, -1200703726L, 1627230884L, -638853529L, 
-1175720003L, -1902919372L, -1560092006L, 257482981L, 2084479615L, 
28756998L, 417038224L, -1634770381L, 210123217L, 729967488L, 
-735132066L, -1418682967L, 145230939L, -1690422166L, -694579956L, 
1190170447L, -1837216763L, -103984452L, 480084882L, -1300021107L, 
67114695L, -1805008978L, 1843104264L, -507154933L, 1274816233L, 
231956920L, -49750426L, 203684609L, -1869230701L, -1251727806L, 
238451188L, -628841481L, -2060281875L, 879431812L, -1932548438L, 
-26084331L, 929598639L, 1960952502L, -660176672L, -2006176733L, 
552072001L, -673145296L, -1697711026L, -1918987079L, 1984630987L, 
-1856979590L, 2043043964L, -1051589441L, 101486997L, 2013149612L, 
-2364542L, 155554141L, -193572777L, 1162536766L, 1482321784L, 
461112411L, 1787925433L, -1525534200L, -597215050L, -167059471L, 
196651555L, -929463694L, -813319996L, 1882140295L, -657496483L, 
-1758476204L, -1780901254L, -4783675L, 991154975L, 2019794598L, 
849612848L, 1683919571L, 1430702321L, -1716997088L, 187060926L, 
-775219511L, -1320471429L, 126724682L, 1239109292L, 2139392431L, 
-1442897563L, 78950172L, -1990569102L, 1495322605L, 501407783L, 
1052809294L, -745284440L, 678646443L, -1164625975L, 1210805208L, 
2059041414L, 1995012961L, -877101325L, 990019938L, 979984340L, 
-893695273L, 1792487629L, -649541532L, -1665735094L, -1341353035L, 
-1679143153L, 820005910L, 55383744L, 802803843L, -1317385055L, 
1186079376L, -1254710930L, -1059184871L, 492131243L, 191529370L, 
89191772L, -169071521L, 1990079541L, 1993609164L, -2138625246L, 
550483325L, -1460128137L, 266096542L, 564293208L, 2070120379L, 
-1722914471L, 1913545448L, -52323562L, 1492446353L, -2118065853L, 
2039147602L, 1283567332L, 1931385127L, -688735875L, 2128113780L, 
1392849498L, 741039781L, -606016321L, -1468813498L, -999060016L, 
725102579L, 1378334481L, 1329985344L, 458301904L, -998906526L, 
1137841128L, -1886709812L, -1340483844L, -1079406606L, 856980608L, 
-1450673932L, 1199617160L, 1443456314L, -506903728L, -863753108L, 
1528946836L, -1284982446L, -1117372704L, -273936180L, -1425024864L, 
-136816254L, 1504573672L, 1175427308L, 102832188L, -373120910L, 
-187946896L, -1965628892L, 2089001528L, 1723181594L, 103944400L, 
-2032159172L, -79410028L, -964127614L, -1730607168L, 1768402236L, 
-2035630448L, -1881418718L, 1037668360L, 82623628L, 1088536604L, 
649372818L, -1370862464L, -1623210988L, 2141315880L, -1712974790L, 
347516112L, -1899416468L, 214013620L, 141680658L, -1346519072L, 
655199180L, -326713888L, 1912835106L, -1033611992L, -383231732L, 
-1413296580L, -819477262L, -518227728L, -1308969148L, -1884950440L, 
545325626L, 870336752L, -1540840772L, -804828652L, 1182379202L, 
465712736L, 1713145212L, 1563059408L, 1340191778L, -97171288L, 
378314124L, -11230788L, -543029198L, -1448651968L, 731913908L, 
-340356792L, -1715850566L, -1983217904L, 366674156L, 252328020L, 
-525089006L, 1891492256L, -1133090868L, 2082283360L, -932533054L, 
-723857880L, 953510316L, -1781914820L, 965763954L, 294817584L, 
121208868L, 529546808L, -1559915814L, 2099566480L, -26544900L, 
-38580844L, 1999733570L, -642463232L, 258836540L, 943964752L, 
420561058L, -2040478904L, -1897186804L, 148183772L, 1218162770L, 
1144360064L, -1768667308L, -1756250136L, -641453318L, 990660432L, 
1066263596L, 984500596L, 1522708114L, 822076000L, 2055516300L, 
1064522080L, 2070255842L, -485135192L, -754329908L, -104474116L, 
-1173582926L, 117523440L, 1040286148L, 1863335256L, -789581446L, 
-1972080208L, -1721226820L, 268369492L, 1009916354L, -345750752L, 
-2089012292L, 1308479568L, 1555323874L, 2044297064L, -1612228788L, 
1067003644L, 1063569138L, 389053696L, 1556511860L, 651193864L, 
2059150778L, -400349744L, -2141657108L, -2142393452L, -704747310L, 
-1589947296L, 2060225868L, -50892000L, 585050754L, 1672991208L, 
-501064724L, 703876668L, 945833586L, 1687645040L, -1392112348L, 
-1598907848L, -1725791846L, 103402960L, -1115568708L, 232263316L, 
2102325890L, -712061504L, 1589991228L, -52714864L, 993175330L, 
203310600L, 731898636L, 1554576284L, -744670190L, -759297152L, 
1436224276L, -1909058264L, -732848070L, -552438832L, -1536730516L, 
-1671648204L, 380121234L, -1879082656L, -957039284L, -186772000L, 
-1852081246L, -1852015704L, 267807884L, -822615108L, -848243598L, 
-338679824L, 930747460L, 1835673688L, 1555771450L, 1371547760L, 
-2079297988L, 1404790548L, -574059838L, -631754016L, 779854972L, 
-1739731760L, -2051046494L, -2091483608L, -350965492L, 900249532L, 
1038549298L, -1644898112L, 174764596L, 1113057992L, 241291962L, 
-437035888L, -1158842644L, -226912684L, -1041320302L, -626972896L, 
1864292300L, -28694304L, -1914036542L, -1301842904L, -769606740L, 
-1577649476L, -1741397518L, -1803069904L, 953358244L, -118443592L, 
-1504638118L, -761764720L, 750467964L, -1880510700L, -1051235006L, 
166915840L, -63603780L, -1812836528L, 1815376162L, -346813880L, 
1600120514L, 444466903L, 1602397985L, 739532518L, -314312732L, 
1397982997L, 1306828607L, 1991695064L, 213368566L, -568846077L, 
-1405220283L, 1398540898L, 2023950800L, 345061113L, -608500693L, 
1665909660L, -1218487350L, 1751086271L, 809866761L, -1801183458L, 
344778444L, 989677213L, -416492761L, 1084095824L, 1883849710L, 
-763777893L, 1544898301L, 416959978L, -1506124152L, 159107121L, 
-940354909L, -2131723612L, -1451136174L, 1130652327L, 149208817L, 
-1312928202L, 485102292L, -1638930843L, -343460753L, 1269534376L, 
644803590L, 1026349363L, 105874837L, 1445071346L, 1382311488L, 
-127203415L, -2043074021L, -1363024916L, -383745030L, -1637208017L, 
-1152114631L, 116421198L, -212610404L, 828864525L, -2005687177L, 
1371501696L, -883105058L, -1973218901L, 329124525L, 234278682L, 
-221294632L, -1758127039L, 1226263283L, -1748038380L, 1326405794L, 
-21219913L, -348747391L, -562172026L, -1443889724L, 1385798901L, 
-2142833313L, -672647240L, -1645675882L, 1078338723L, -1629331867L, 
-90633342L, 1310451952L, 708513945L, 987457675L, 2000736636L, 
879972266L, 2052648927L, -998089367L, -2005606018L, -1180552852L, 
-1978897987L, 1896798855L, -1116676496L, 1558488334L, 1903503931L, 
1928106269L, 853599178L, -1180459800L, -2085732399L, -531238461L, 
-1823606076L, 233126258L, -327146425L, -1655658479L, 1903292822L, 
1174512884L, -37794171L, 692905935L, 811599560L, -801071258L, 
656459155L, 1151104757L, -869828910L, 991740192L, -151162615L, 
1840313915L, -214242420L, 656927258L, -424379761L, -554064423L, 
1816685166L, -1822737924L, 832396141L, 162735383L, -1644949280L, 
1450788542L, 1498391691L, -630910195L, 583807802L, 1018858360L, 
-1714702047L, -1333931565L, 1217429748L, 899727746L, -1409547241L, 
2090226401L, 1974438950L, 73062692L, -1590224427L, 1875948927L, 
-77542376L, 784548662L, -28183101L, -551650299L, 1792382882L, 
-851856496L, 1338357561L, -47094805L, -1823492900L, -2081288950L, 
-2026916865L, 1976485449L, 1206318046L, 206949260L, -1162278051L, 
174685031L, 743813264L, -1900990802L, 1033046875L, 155999037L, 
930714026L, 362217032L, -838316431L, -1228648477L, -895149340L, 
-232250862L, -1254320665L, 1257390513L, -1115109386L, 1448999444L, 
195626277L, -924994001L, -54758424L, -978942778L, 1919340052L
)
